Page 106 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 106

Home

    matters worse, the Federal Reserve reduced the money
    supply by more than a third between 1929 and 1933,
    doing just the opposite of what it had supposedly been
    created to do.

    Those in on the game sold their stock at the peak of
    the market, and bought it back for five cents on the
    dollar. Thus, they made vast fortunes out of the
    misfortunes of others. The Great Depression was
    actually a massive transfer of wealth, out of the hands of
    the American people who had worked to create it, and
    into the hands of the Money Barons who had engineered

    dollar.

    While the American people were being set up for
    financial disaster, the perpetrators were also working to
    get their man into the White House. The man they
    selected was a Harvard graduate whose family had been
    in New York banking since the eighteenth century. Their
    candidate had pursued a career on Wall Street and was
    on the board of directors of eleven corporations. He was
    first backed for governor of New York and then for
    president of the United States. To gain the confidence of
    the international socialists, he had written an article for
    the Council on Foreign Relations showing his support for
    world government. This article was published in their
    magazine, Foreign Affairs, in July 1928. It may have
    been more than coincidental that he also lived in a house

    101

    Building Modern Babylon

    the stock market crash.

    next door to the Council on Foreign Relations’

    headquarters in New York.